# Welcome to Geobay


[![image](https://img.shields.io/pypi/v/GeoBay.svg)](https://pypi.python.org/pypi/GeoBay)


**python package for geog 510**


-   Free software: MIT License
-   Documentation: <https://Caseyshea96.github.io/GeoBay>


## Features

-   TODO
